@@ -8,30 +8,40 @@
 #include <QtGui/QApplication>
 #include <QObject>
 #include <QTranslator>
+#include <QtSingleApplication>
 
 int main(int argc, char *argv[])
 {
     // register required types for inter-thread communications
-    QApplication a(argc, argv);
-    a.setApplicationName(APP_NAME);
-    a.setOrganizationName("PetrSU");
-    a.setOrganizationDomain("cs.karelia.ru");
+    QtSingleApplication app(argc, argv);
+
+    if (app.isRunning())
+        return 0;
+
+    app.setApplicationName(APP_NAME);
+    app.setOrganizationName("PetrSU");
+    app.setOrganizationDomain("cs.karelia.ru");
 
     QString locale = QLocale::system().name();
     QTranslator translator;
     translator.load(QString(APP_NAME) + "_" + locale,
         DATAPREFIX"/qt4/translations/");
-    a.installTranslator(&translator);
+    app.installTranslator(&translator);
 
     QTranslator commontr;
     commontr.load(QString("mysocials_core") + "_" + locale,
         DATAPREFIX"/qt4/translations");
-    a.installTranslator(&commontr);
+    app.installTranslator(&commontr);
+
+    QTranslator widgettr;
+    widgettr.load(QString("msaqtwidgets") + "_" + locale,
+        DATAPREFIX"/qt4/translations");
+    app.installTranslator(&widgettr);
 
     QTranslator qtTranslator;
     qtTranslator.load("qt_" + QLocale::system().name(),
                       QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-    a.installTranslator(&qtTranslator);
+    app.installTranslator(&qtTranslator);
 
     Q_INIT_RESOURCE(mysocials_res);
 
@@ -41,18 +51,23 @@ int main(int argc, char *argv[])
 #endif
 
     // Style sheet
-#ifdef Q_WS_MAEMO_5
-    QString styleName = "maemo5";
-#else
     QString styleName = "default";
+#ifdef Q_WS_MAEMO_5
+    styleName = "maemo5";
+#endif
+
+#ifdef  MEEGO_EDITION_HARMATTAN
+    styleName = "harmattan";
 #endif
 
     QFile styleFile(":/res/qss/" + styleName + ".qss");
     styleFile.open(QFile::ReadOnly);
-    a.setStyleSheet(QString::fromLatin1(styleFile.readAll()));
+    app.setStyleSheet(QString::fromLatin1(styleFile.readAll()));
     styleFile.close();
 
     MainWindow w;
+    app.setActivationWindow(&w);
+
     w.showMaximized();
-    return a.exec();
+    return app.exec();
 }
