@@ -31,6 +31,10 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->stackedWidget->addWidget(newsPanel);
     ui->stackedWidget->addWidget(msgComposer);
 
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
+    ui->mainToolBar->setStyleSheet("QToolBar{background: qlineargradient(spread:pad, x1:0, y1:0.5, x2:1, y2:0.5, stop:0 rgba(0, 0, 0, 255), stop:1 rgba(40, 36, 40, 255));}");
+#endif
+
     connect(this->sm, SIGNAL(errorOccured(QString, QTransport::Action, bool)),
             this, SLOT(gotErrorMsg(QString, QTransport::Action, bool)));
 
@@ -143,8 +147,12 @@ void MainWindow::createActions()
     moreAction = new QAction(isShowLabels ? tr("&More") : "", this);
     moreAction->setIcon(QIcon(":/res/more.png"));
     moreAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_0));
+#ifdef ENABLE_DEBUG
     moreAction->setCheckable(true);
     connect(moreAction, SIGNAL(triggered()), SLOT(onMoreTriggered()));
+#else
+    moreAction->setCheckable(false);
+#endif
     actionGroup->addAction(moreAction);
 
     connect(actionGroup, SIGNAL(triggered(QAction*)), SLOT(onActionTriggered(QAction*)));
@@ -279,10 +287,14 @@ void MainWindow::onNewsTriggered()
 // More
 void MainWindow::onMoreTriggered()
 {
-//    if (this->testAttribute(Qt::WA_Maemo5PortraitOrientation))
-//        this->setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
-//    else
-//        this->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+#ifdef ENABLE_DEBUG
+#ifdef Q_WS_MAEMO_5
+    if (this->testAttribute(Qt::WA_Maemo5PortraitOrientation))
+        this->setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
+    else
+        this->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+#endif
+#endif
 }
 
 void MainWindow::openImage(Photo photo)
@@ -354,12 +366,10 @@ void MainWindow::showNotification(QString message)
 {
 #ifdef Q_WS_MAEMO_5
     QDBusMessage msg = QDBusMessage::createMethodCall("org.freedesktop.Notifications", "/org/freedesktop/Notifications",
-                                                     "org.freedesktop.Notifications", "SystemNoteDialog");
+                                                     "org.freedesktop.Notifications", "SystemNoteInfoprint");
 
     QList<QVariant> args;
     args.append(message);
-    args.append(static_cast<quint32>(0));
-    args.append("ok");
 
     msg.setArguments(args);
 
